@@ -11,11 +11,11 @@ mod system_result;
 
 pub use attribute::{attr, Attribute};
 pub use contract_result::ContractResult;
-#[cfg(feature = "stargate")]
-pub use cosmos_msg::GovMsg;
 pub use cosmos_msg::{wasm_execute, wasm_instantiate, BankMsg, CosmosMsg, WasmMsg};
 #[cfg(feature = "staking")]
 pub use cosmos_msg::{DistributionMsg, StakingMsg};
+#[cfg(feature = "stargate")]
+pub use cosmos_msg::{GovMsg, VoteOption};
 pub use empty::Empty;
 pub use query::QueryResponse;
 pub use response::Response;
